Class: Google::Shopping::Css::V1::ProductWeight

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/css/v1/css_product_common.rb

Overview

The weight of the product.

Instance Attribute Summary collapse

Instance Attribute Details

#unit::String

Returns Required. The weight unit. Acceptable values are:

* "`g`"
* "`kg`"
* "`oz`"
* "`lb`".

Returns:

  • (::String)

    Required. The weight unit. Acceptable values are:

    * "`g`"
    * "`kg`"
    * "`oz`"
    * "`lb`"


304
305
306
307
# File 'proto_docs/google/shopping/css/v1/css_product_common.rb', line 304

class ProductWeight
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::Float

Returns Required. The weight represented as a number. The weight can have a maximum precision of four decimal places.

Returns:

  • (::Float)

    Required. The weight represented as a number. The weight can have a maximum precision of four decimal places.



304
305
306
307
# File 'proto_docs/google/shopping/css/v1/css_product_common.rb', line 304

class ProductWeight
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end